package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````!1<``#0```"(@0````0`!30`(``)
M`"@`&P`:``$``'"D?```I'P``*1\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````"P?```L'P```4```````$`
M`0```+!\``"P?`$`L'P!`)`#``"D$P``!@```````0`"````N'P``+A\`0"X
M?`$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DL'P`
M`+!\`0"P?`$`4`,``%`#```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`7P80OUJG(B:6EF?2,WB,*RV^^9L$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"$P```!-````4```
M`%0```!5````70```%X```!?````80```&(```!D````90```&8```!G````
M:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%
MU>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[
M20``````````````````````````/!(````````#``L```````"``0``````
M`P`6`$`"`````````````!(```#4`@`````````````2````J`(`````````
M````(@```.T"`````````````!$```":`P`````````````2`````0``````
M````````(````*8!`````````````!(```"'`@`````````````2````Q0(`
M````````````$@```/@``````````````!(````)`P`````````````1````
M6P(`````````````$@```%P!`````````````!(```!B`@`````````````2
M````1P(`````````````$@```'0``````````````!(```#S````````````
M```2````:@(`````````````$@```"0"`````````````!(```#J`0``````
M```````2````]P(`````````````$@```&,"`````````````!(```#[`0``
M```````````2````"`(`````````````$@```-$``````````````!$```!.
M`0`````````````2````LP``````````````$0```!P!`````````````!(`
M``".`@`````````````2````@`(`````````````$0```(H!````````````
M`!(```"R`0`````````````2````=P$`````````````$@```'@"````````
M`````!(```"K`0`````````````2````@P$`````````````$@```-L"````
M`````````!(````J`0`````````````2````'0``````````````(````!T"
M`````````````!(```#4`0`````````````2````,@(`````````````$@``
M`%0``````````````!(```"7`@`````````````2````@P``````````````
M$@```)4!`````````````!(```"W`@`````````````2````CP``````````
M````$@```$,!`````````````!(````"`@`````````````2````.0(`````
M````````$@````D!`````````````!(```!&```````````````2````_0``
M````````````$@```&P!`````````````!(```!-`@`````````````2````
MP```````````````$@```!8"`````````````!(```#-`@`````````````2
M````W```````````````$@```"L"`````````````!(```!C````````````
M```2````[@(`````````````(0```)X"`````````````!(```"D````````
M```````2````.@$`````````````$@```"P``````````````"````#O`@``
M```````````1````V0$`````````````$@```!`"`````````````!(```#.
M`0`````````````2````X0$`````````````$@```+H!`````````````!(`
M``"W`P``5)`!```````0`!<`HP,```$M``#H````$@`-`-L#``!9)0``X`4`
M`!(`#0#H`@``214``+P!```2``T`:0,``)4=```$````$@`-`'H#``!`@`$`
M`````!``%P!W!```F1T``*0!```2``T`K00``#DK``#(`0``$@`-`&,$``!`
M@`$``````!``%P#"`P``/1\``!8````2``T`Z`,``-DY``#4````$@`-```$
M``#$.P``!````!$`#P`_!```5)`!```````0`!<`1`0``%20`0``````$``7
M`&\$``"U'```.````!(`#0"$!```>20``.`````2``T`E@0``/$C``!X````
M$@`-`/,#````@`$``````!``%@#/`P``51\``+`````2``T`KP,``$"``0``
M````$``6`#4$```\@`$`!````!$`%@!9`P``J3L```(````2``T`)00``&D[
M``!`````$@`-`/D#```%%P```````!(`#0"D!```83D``'@````2``T`]0,`
M``"``0``````(``6`(@#``!I)```$````!(`#0"V`P``5)`!```````0`!<`
M#P0``.T<``"H````$@`-`%D$``"M.@``O````!(`#0!,!```!2```.P#```2
M``T``%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`7U]E<G)N;U]L;V-A=&EO;@!R96%D`&]P96XV-`!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M
M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`&QS=&%T-C0`7U]S=')N8W!Y
M7V-H:P!O<&5N9&ER`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R
M96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU
M+C,T`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N
M<V\N,P!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S
M=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L
M`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT97)N86QS7U!!
M4E]"3T]4`$=,24)#7S(N-`!'3$E"0U\R+C,S``````````(``@`"``(``@`!
M``,``@`"``(`!``"``$`!0`"``$``0`"``(``@`"``4``@`"``$``0`!``$`
M`@`"``$``P`!``(``P`"``(``0`!``(``@`"``$``@`!``,``@`!``$``@`"
M``$``0`!``$``@`!``(``@`!``(``0`"``(``0`!``$``@`"``(``P`"``,`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0````$``0!%`P``$````"`````4:6D-```$`,,$
M`````````0`!`"L#```0````(````!1I:0T```,`PP0````````!``(`.P,`
M`!``````````LY&6!@``!0#-!```$````!1I:0T```(`PP0```````"P?`$`
M%P```+1\`0`7````R'X!`!<```#L?@$`%P```/1^`0`7````!(`!`!<````,
M@`$`%P```!"``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!`!<`
M```H@`$`%P```#"``0`7````-(`!`!<````\@`$`%P```,Q^`0`5!0``T'X!
M`!4(``#4?@$`%0T``-A^`0`5#P``W'X!`!4;``#@?@$`%1T``.1^`0`5(```
MZ'X!`!4I``#P?@$`%38``/A^`0`50```_'X!`!5%````?P$`%48``-1]`0`6
M`P``V'T!`!8$``#<?0$`%@4``.!]`0`6!P``Y'T!`!8)``#H?0$`%@H``.Q]
M`0`6"P``\'T!`!8,``#T?0$`%@X``/A]`0`6$```_'T!`!81````?@$`%A(`
M``1^`0`6$P``"'X!`!84```,?@$`%A4``!!^`0`6%@``%'X!`!87```8?@$`
M%A@``!Q^`0`6&0``('X!`!8:```D?@$`%AP``"A^`0`6'@``+'X!`!8?```P
M?@$`%B$``#1^`0`6(@``.'X!`!8C```\?@$`%B0``$!^`0`6)0``1'X!`!8F
M``!(?@$`%B<``$Q^`0`6*```4'X!`!8I``!4?@$`%BH``%A^`0`6*P``7'X!
M`!8L``!@?@$`%BT``&1^`0`6+@``:'X!`!8O``!L?@$`%C```'!^`0`6,0``
M='X!`!8R``!X?@$`%C,``'Q^`0`6-```@'X!`!8U``"$?@$`%C<``(A^`0`6
M.```C'X!`!8Y``"0?@$`%CH``)1^`0`6.P``F'X!`!8\``"<?@$`%CT``*!^
M`0`6/@``I'X!`!8_``"H?@$`%D(``*Q^`0`60P``L'X!`!9$``"T?@$`%D<`
M`+A^`0`62```O'X!`!9)``#`?@$`%DH``,1^`0`62P``"$`MZ4$!`.L(@+WH
M!.`MY03@G^4.X(_@"/"^Y7!K`0``QH_B%LJ,XG#[O.4`QH_B%LJ,XFC[O.4`
MQH_B%LJ,XF#[O.4`QH_B%LJ,XEC[O.4`QH_B%LJ,XE#[O.4`QH_B%LJ,XDC[
MO.4`QH_B%LJ,XD#[O.5X1_WG`,:/XA;*C.(T^[SE`,:/XA;*C.(L^[SE`,:/
MXA;*C.(D^[SE`,:/XA;*C.(<^[SE`,:/XA;*C.(4^[SE`,:/XA;*C.(,^[SE
M`,:/XA;*C.($^[SE>$?]YP#&C^(6RHSB^/J\Y0#&C^(6RHSB\/J\Y7A'_><`
MQH_B%LJ,XN3ZO.4`QH_B%LJ,XMSZO.4`QH_B%LJ,XM3ZO.4`QH_B%LJ,XLSZ
MO.4`QH_B%LJ,XL3ZO.4`QH_B%LJ,XKSZO.4`QH_B%LJ,XK3ZO.4`QH_B%LJ,
MXJSZO.4`QH_B%LJ,XJ3ZO.4`QH_B%LJ,XISZO.4`QH_B%LJ,XI3ZO.4`QH_B
M%LJ,XHSZO.4`QH_B%LJ,XH3ZO.4`QH_B%LJ,XGSZO.4`QH_B%LJ,XG3ZO.4`
MQH_B%LJ,XFSZO.4`QH_B%LJ,XF3ZO.4`QH_B%LJ,XESZO.4`QH_B%LJ,XE3Z
MO.4`QH_B%LJ,XDSZO.4`QH_B%LJ,XD3ZO.4`QH_B%LJ,XCSZO.4`QH_B%LJ,
MXC3ZO.4`QH_B%LJ,XBSZO.4`QH_B%LJ,XB3ZO.5X1_WG`,:/XA;*C.(8^KSE
M`,:/XA;*C.(0^KSE`,:/XA;*C.((^KSE`,:/XA;*C.(`^KSE`,:/XA;*C.+X
M^;SE`,:/XA;*C.+P^;SE`,:/XA;*C.+H^;SE`,:/XA;*C.+@^;SE`,:/XA;*
MC.+8^;SE`,:/XA;*C.+0^;SE`,:/XA;*C.+(^;SE`,:/XA;*C.+`^;SE`,:/
MXA;*C.*X^;SE`,:/XA;*C.*P^;SE`,:/XA;*C.*H^;SE`,:/XA;*C.*@^;SE
M`,:/XA;*C.*8^;SE`,:/XA;*C.*0^;SE`,:/XA;*C.*(^;SE`,:/XA;*C.*`
M^;SE<+5;38BP6TM]1%M,S>D$$`6H`Y($J0.J?$3K6!MH!Y-/\``#__=.[U1*
M54NB6.!8$48"\!?[4TOC6!UX`"UKT%%+Y%@@:/_WUN\#1B!HD_C&(T+P`@*#
M^,8C__?,[P6=D/C&,RH=`S5#\`$#LO&`3X#XQC-STI``__?H[D-*!)P#1GI$
M0DEY1%!@(F@:8$%*!9AZ1-I@0$H!*`EH>D298%I@7MTA'03K@`X#\0P,4?@$
M2TSX!$]Q1?G1`S`W3@`A`)$J1GY$0_@@$#5)\&AY1/_W/.\$1GBS,DT&KGU$
MZ&C_]Y;N,$@Q1GA$`/#O^$"S+DM[1-AH__=8[O_W'.\L2AQ+>D336!IH!YM:
M0$_P``,IT2!&"+!PO?_WC.XE2GI$T&`0L__W.NX72^18(&C_]V+O@/A[5X7G
M\&C_]S[O!$;*YZAH$+$!\#?[T><:2#%&>$0`\+OXJ&``*,G0\^?_]Q3O!""J
MY__W-.X!(/_WGNYT:`$`#`$``&1H`0`H`0``,`$``!@!```4`0``=FH!`&IJ
M`0""*0``="D``#1J`0`S!@``'&H!`.@F```&:@$`>F<!`-II`0`<)@``3_``
M"T_P``X"O&I&!+0!M-_X)*`(HYI$W_@@P%KX#,!-^`3-!DM:^`,P!DA:^```
M__=&[O_W[NZ,9@$```$``"0!```L`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>
M_R\!'/__ZFQF`0`@`0``!D@'2P=*>$1[1'I$@T(#T`5+TU@#L1A'<$<`O\9H
M`0#$:`$`2F8!``@!```(2`E+>$0)2GM$&QIZ1-D/`>NC`4D0`]`%2]-8`[$8
M1W!'`+^<:`$`F&@!`!QF`0`T`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(2WM$
M&&C_]T3M__>__P9+`2)[1!IP"+UF:`$`[&4!``0!```::`$`1F@!`,3G`+\M
MZ?A#@48?2WM$`"@VT!Y*FUC3^`"`N/$`#S'0!7@/1@`M&+\]+12_`24`)1/1
MV/@`0&RQ1D8@1BI&24;_]USN$+EC73TK$-!6^`1/`"SRT2!&O>CX@P5&%?@!
M/P`K&+\]*_G1I>L)!>'GINL(!@$U+$2V$#Y@($:]Z/B#!$;GYT1&Y>>H90$`
M.`$``#A*.4MZ1"WI\$&>L--8&V@=DT_P``,0L0-X!$9CN3-*,4MZ1--8&F@=
MFUI`3_```U71'K"]Z/"!__=B[05&`"CMT"M/?T0H1O_W_NT`*#70PWP`\1,&
M+BL"T7-X`"ORT,-\+BLQT"!&__=Z[8!&,$;_]W;M0$0",/_W3NT[1D_P_S(!
M(0&6!D8`E/_WB.T"J3!&__<`[0$P,$8%T`:;`_1P0[/U@$\7T/_W^NPP1O_W
MLNPH1O_WR.T`*,G1*$;_]^CM($;_][CLJ>=S>"XKRM&S>``KM]#&Y__WDO_F
MY__WS.P`OR!E`0`,`0```F4!`'`C```72AA+>D00M01&G+#36&E&&V@;DT_P
M``/_]X[LH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH&YM:0$_P``,+
MT1RP$+T`(/'G`B$@1O_W;NVP^H#P0`GIY__WDNPL9`$`#`$``/QC`0`MZ?!#
M#D8L22Q+K?6`77E$@[`$1@WU@%`$,-_XI(#+6`&O0/;_<CE&&V@#8$_P``,D
M2/A$>$3_]YSLL/$`#!O=`JT,\?\Y3405^`0\@[NY\0`/$=!*1B\A.$;_]R[M
M6+$92UCX`S`8:/_W:.U+1CI&(4;_]T#M">`32UCX`S`8:/_W7.TR1B%&__=L
M[`]*#?6`40I+!#%Z1--8&F@+:%I`3_```P;1#?6`70.PO>CP@^%&S^?_]S#L
MMF,!``P!``"28P$`*"(``!0!```N8P$`6$I92WI$+>GP1PQ&@K`%1M-8W_A8
M@1MH`9-/\``#"WCX1#TK"+\!-"!&__>"[&E&!D8H1O_WAOZ!1@`H5-#_]WCL
MAD)'V4I+`)]8^`.`OP`K>``K&+\]*Q2_`2,`(P?0*T83^`$O`"H8OSTJ^=%;
M&[`<V/@`8!A$__<V[/!1Z+'8^``P*$;961#X`3L+<``K&+\]*PG02AP0^`$[
M$48"^`$[/2L8OP`K]M$*1CTC"W`4^`$[`O@!/P`K^=$M2BI+>D336!IH`9M:
M0$_P``-&T0*PO>CPAPGQ_SD4^`$["?@!/P`K^='IYR%+6/@#@-CX`'`[:(.S
M.T93^`0O248)\0$)`"KXT0,QB0`;2GI$$VB[N0A&`2,38/_WYNN"1@`HS-`Y
M1D_JB0<Z1O_W5.O(^`"@S?@`D`GQ`0D`(TKX*3"&YSA&__>:ZX)&R/@````H
MM-!/ZHD'[.>91@@AU>?_]W3K`+_P8@$`#`$``-1B`0`X`0``-&(!`&1D`0`P
MM1%,$4N#L'Q$Y5@H:/_W<.PH:/_W;.P-2@Y+#DE[1*)8>43_]_+K*&C_]V+L
M"TL+2@`D"TE[1'I$S>D`-'E$__<.[`.P,+UP80$`%`$``!`!``!V7P``_A\`
M`-(B``"Q#@``_A\``!"U"$P(2WQ$XU@8:/_W/.P&2@=+!TE[1*)8>42]Z!!`
M__>^NPIA`0`4`0``$`$``!9?``">'P``)$HPM21+>D2M]0!=B;`-]0!1!:S3
M6!PQ&V@+8$_P``/_]VSK'4E!\@$"'4MY1,WI``%[1`$A($;_]XKK#?6`41@Q
M($9/](!2`Y'_]QSK!!ZXOP`E"MM@'/_W..L%1BBQ`YDB1O_WMNH`(RM5#4H-
M]0!1"4L<,7I$TU@::`MH6D!/\``#!-$H1@WU`%T)L#"]__?,ZM)@`0`,`0``
ME!\``((?``!B8`$`__>JOUM*+>GP3P9&6DMZ1*WUA%V#L%E(#?6$5`WQ&`C3
M6`U&>$1!1@0T&V@C8$_P``/_]R7]+R$$1C!&__<BZ\"Q3T@Q1GA$__=X_C!&
M34H-]8112$L$,7I$TU@::`MH6D!/\``#0/"#@`WUA%T#L+WH\(\P1O_W^NJ!
M1BA&__=\ZD%)>43_]V#K`"C9T#]+!T;?^/R@>T0%DSY+^D1[1`23.W@`*S[0
M++$Y1B!&__<2Z@`H0=`X1O_WV.I"'KL8NEPO*@;1`"4=<`$X$_@!+2\J^=`)
M\0$#`T2S]8!?L-HM2B&M`2%31GI$*$;-Z0$F3_2`4@"7__?8ZD%&*$;_]U#J
M*+D*FP/T<$.S]0!/'=`B20`@>43_]QCK!T8`+Y#0.W@`*\#1!+,C>"XK`M`%
MGP$@S^=C>``K^=$920`@>43_]P+K!T8`+^K1>N<!(2A&__?NZ@`HV]$22"E&
M>$3_]^W]*$;_]PCJ<><$GP$@L>?_]PCJ(F`!``P!``#\'@``YAX``-A?`0"X
M'@``AAX``*0>``!^'@``8!X``"@>``#^'0``T!T```-X.[%"'"\K"+\01A+X
M`3L`*_C1<$<`OQ"UJ+,#>`1&D[/_]U#J0QXC1)Q",M(:1@+@$T:B0BW0$T82
M^`$9+RGWT)Q")M(!.YQ")=`:>"\J^=$!.P/@$7@!.R\I`M$:1IQ"^-,2&Y,<
ML_6`7XB_`"`)V!%((49/](!3`3)X1`1&__>>Z2!&$+T,2+WH$$!X1/_WG+F<
M0MS1(W@O*P70"$B]Z!!`>$3_]Y&Y!DB]Z!!`>$3_]XNY`+^88`$`YAP``/P<
M``#$'```W4K?^'C#WDMZ1'"U_$0,\0P,C+#;3M-8#?$(#GY$`:P;:`N33_``
M`]=-O.@/`*[H#P!]1+SH#P"NZ`\`W/@`,*[X`#`A1C!&__?B^["QSTL!F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]\S[`"CHT<1.?D0A
M1C!&__?$^["QP$L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]Z[[`"CHT;9.?D0A1C!&__>F^["QL4L!F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_]Y#[`"CHT:A.?D0A1C!&__>(^["QHDL!F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]W+[`"CHT9I.?D0A
M1C!&__=J^["QDTL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]U3[`"CHT8Q.?D0A1C!&__=,^["QA$L!F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_]S;[`"CHT7Y.?D0A1C!&__<N^["Q=4L!F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]QC[`"CHT7!.?D0A
M1C!&__<0^["Q9DL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]_KZ`"CHT6).?D0A1C!&__?R^K"Q5TL!F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_]]SZ`"CHT51.?D0A1C!&__?4^K"Q2$L!F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_][[Z`"CHT49.?D0A
M1C!&__>V^K"Q.4L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]Z#Z`"CHT3A((49X1/_WF?H!1ABQ-DAX1/_W\?LU2"%&>$3_]X[Z`488
ML3)(>$3_]^;[,4@A1GA$__>#^@%&J+$O2'A$__?;^RY)+DAY1'A$__?5^RU*
M%DMZ1--8&F@+FUI`3_```QW1#+!PO2A((49X1/_W9OH!1B"Q)4AX1/_WOOOA
MYR1)"B(-\1D`>43_]]3H`"C8T2!(#?$C`7A$__>N^]'G_O?0[P"_N%T!`-!;
M```,`0``P!P``(Y=`0`X`0``:AP``#8<```&'```TAL``*8;```&&P``.AL`
M``H;``#:&@``(AH``&P:``!(&@``:AH``'(:``!T&@``H!D``(X:``#H&0``
MFEH!`$H:``#6&0``0AH``+89```72QA)&$I[1'E$`+48:(.PBEA#'!)H`9)/
M\``"#-`32A%+>D336!IH`9M:0$_P``,3T0.P7?@$^PU(:49X1/_W\?DPL0!X
M,"@8OP`H%+\!(``@"$M[1!A@X>?^]V;O`+\.7`$`S%D!``P!``"R60$`^!@`
M`,!;`0`(M?[W%N_^]PCO`+$`:`B]+DHO2WI$\+4N3H>P!4;36'Y$!*DP1AMH
M!9-/\``#__>]^1"Q`W@$1HNY)THD2WI$TU@::`6;6D!/\``#/-$C2"E&>$0'
ML+WH\$#_]P6[*4;^]\CN6+$>2AE+>D336!IH!9M:0$_P``,FT0>P\+TH1O[W
MBN\'1B!&_O>&[SA$`C#^]U[O$TL42@$A>T0"E'I$`)4!DD_P_S($1O[WE.\/
M2@=+>D336!IH!9M:0$_P``,$OR%&,$;%T/[W\NY(60$`#`$``"@9```>60$`
M]A@``/)8`0#2%P``RA<``*I8`0`MZ?!/W_A$%:WU`4W?^$!%@;#?^$"E?$1`
MKR(=I_%T`P>0#?4`1=_X,`4$\1`,_#4H-'A$I_%H#J?QX`;Z1$%8"6@I8$_P
M``&G\5P%!\J#Z`<`O.@/``_%G.@#`(7H`P"4Z`<`CN@'`-_X\`0Q1GA$__<D
M^2"Q`W@$1@`K0/!<@?[W7N[^]U#N`"@`\&V!!6@`+0#PDX$H1O[W!N]```$P
M_O?>[BIX@$:"L=_XM+1$1OM$($8`DEM&3_#_,@$A`C3^]Q#O%?@!+P`J\M'?
M^)0$I_%8!7A$`N!5^`0+B+$Q1O_W[/@$1@`H]M`#>``K\]#_]Z3Y`"COT"!&
M_O=<[@1&T+E/\``)I_%T"P?KB0)2^'1,A+$)\0$%"^N%!2)X4K$@1@GQ`0G_
M]XGY`"A;T57X!$L`+/+1`"0@1O[WMNZ#1D!&_O>R[H-$"_($2UA&_O>([M_X
M%#1/\/\R`2%[1`*3W_@(-,WX#("`1GM$`9/?^``T`)1[1/[WMNY/].!Q0$;^
M]\3N`3`%T?[WINX!:!$I0/#"@#%&0$;^]^SM!49(L_1)!YOT2EKX`0!/\``*
M&VAZ1,WX`(`!(0!H_O?&[N]*#?4`0>%+_#%Z1--8&F@+:%I`3_```T#PMX%0
M1@WU`4T!L+WH\(\@1O[WY.T$1@`HB]"AYU?XT#P#]'!#L_6`3\[15_C(3/[W
MG.V$0LC15_C0/,/S"`.S]>!_P=%81O[W(.Z"1M9(,49X1/_W1_@!1@`H`/#%
M@`>;&&C_]P'[@T8`*`#PO8!81O[W+NX$1@,H#]G,200X6$1Y1/[W6NU`N00L
M`/`N@5Q$%/@%/"\K`/`H@<5,?$0C:%H<`/"E@``K`/"W@,%)PDAY1-_X")-X
M1,%/__=Q^<%._O?Z[<!+3_#_,@$A>T0#D[Y+^43-^`"`?T1[1,WI`3"[2U!&
M?D1[1/[W$.X4X/[W".X#:!$K%]'^]][M`36$1DM&(D8!(5!&S>D#5\WI`6S-
M^`"`_O?Z[4_TX'%01O[W"NX$1D,<XM!`1O[W+.VI2%%&>$3_]S3Y4$;_]P7^
M4N>62@>;6O@"`$_P``H;:*)*S>D`@0$A>D0`:/[W"NY"Y__W\OV=2H-+#?4`
M07I$_#'36!IH"VA:0$_P``-`\/B`($8-]0%-`;"]Z/!/_O<DO8!&I_%H!`?K
MB`-3^&@,R+$(\0$+!.N+!03@5?@$"XBQ"_$!"S%&V$;^]Y3_`"CTT`-X`"OQ
MT/[W"NT%1@`H?_1VKN#G@DT-(/[W5NU3(H!&?41VYJA&U.<'F]/X`+`^YWQ(
M,49X1/[W=?\`*`#PBH`#>``K&+\P*Q6_`2,`(P$C(V`8OR-@?_1)KUA&`"'^
M]R[M!$8`*#_T0:]/\/\S;_`1`@(F/1\`EO[W#NT&(BE&($;^]XSL%_@$/!NY
M%_@#/$,K8=``(P`B`),@1@`C_O?\[`#PY?\&1@/@*48P1@'P&_A/]`!"*48@
M1O[W<.P"'O/<W_ADL2!&I_$P"?[WLNVG\44%,4;[1$Q&I_$Q!J?Q1``!\&OX
M%?@!+R!&`));1D_P_S(!(?[W*NT"-*Y"\M%*2@$AS?@(D%!&>D1(2\WI`((`
M(@?X""Q[1$9*>D0#DD_P_S+^]Q+M'N<'FUQH`"P_]-.N($;^]^SL`RA_]LVN
M/4D$."!$>43^]Q;L`"@(OZ-&PN8@8(#G%_@"/$$KF=$7^`$\0RN5T3MX2"N2
MT7MX12N/T4_P_S-O\#D"($8`EO[WBNPI1BDB($;^]PCL*TLK24_P_S)[1,WI
M`E,I2WE$4$;-Z0"!>T0!(?[WT.S;YO[W.NP,`0``EEH!`#!8`0`Z6`$`[A8`
M`,`7``!$%P``*!<``!H6```$%P``'`$``!@7``"D5@$`]!8``,P6```X6`$`
MS!4``#X5``"J%@``3!<``,@4``!8%P``TA0``(86``!2%```7A4``"A5`0"P
M%````!0```(4``#B$@``A!0``$@5``!.%```SA0``$X2``#V$P``7TA@27A$
M\+5?2X.P7TI!6'M$;D8):`&13_```9Q8(&C^]_#L!48@:/[W[.PQ1I7X:#"`
M^&DP5DAX1/[W3_X0L0-X,2MZT/_W0?H@:/[WVNQ020,C`2)Y1/[W'NP%1FBQ
M(&C^]]#L*VE+2AEH>D3^]][K*VD;:)MH6P)NU"!H_O?"[$9)`R,!(GE$_O<&
M[`5&>+%#2#%&>$3^]R#^!T8@:``O3]#^]Z[L*VDZ1AEH_O>^ZR!H_O>F[`5&
M(&C^]Z+L.$D!(GE$_O<2[#=*`48H1GI$-DW^]ZKK(&C^]Y3L`T9]1#-(`"(Q
M1GA$@_AI(/[W]?T$1JA@L+%/].!Q($;^]Q;L0AP#1A$H&+\!*B_8*4H<2WI$
MTU@::`&;6D!/\``#(]$#L/"]:&C_]WK\!$:H8``HX=$@2'A$_O?JZT-X`"N#
MT(#G_O=>[!Q+*FE[1!!H6V@9:/[WN/ZKYR!H_O=2["MI&6C^]_3KB.?^]SKK
M%$DB1A1(>41X1$EH"6C^]\CKB%(!``P!``!\4@$`%`$``)@1```R$P``(!,`
M``P3``#R$```U!(``.`2```H5`$`E!```'I1`0""$@``O%,!`)13`0!F$@``
M,DHS2WI$\+4'1H.PTU@;:`&33_```__W'?D#>`1&.[%"'"\K"+\41A+X`3L`
M*_C1*$X]'AB_`25^1#-H6APLT``K#+\`)07P`05=N2)*($MZ1--8&F@!FUI`
M3_```S+1`[#PO3MX`"OPT!Q)!"(@1GE$_O?,ZP`HZ-$92A1+>D336!IH`9M:
M0$_P``,;T3A&`["]Z/!`_O>#O1)(:49X1/[W./UHL0-X`"L8OS`K"K\`(P$C
M,V#)T`$C,V``+<70T.<P8,+G_O>HZ@"_P%`!``P!``#,4@$`=%`!`&P0``!&
M4`$`A@\``"WI\$\`\4`!W_A@2]_X8#NM]2-]?$3N1G)&`/&`#``GXU@;:*&3
M3_```U'I`F178-=@$#(VND+X$&PC"B4"`_1_0P@Q0^H48P7T?P5#Z@1C845#
MZ@4#0O@(/.;1K?$(!@[U_'<`(X1&-$96^`@/U.D&A2)OU/A(H&%OU/A,D(+J
M"@)T:(+J"`*!Z@D!0D!I0,;XA#!A0)08T@^^0D+J00)"Z@0"QOB`(-[18$;>
M^`!0W.D#)H1HW.D`>4_JE`@"F4CJ@GA']ID2Q?:"(DCJA'@$:JT83^K7;-WX
M$.!,ZDD<+1F$:4SJ1QP<ZP4%W?APH(;J!`R$:`SJ!`R$:8SJ!`P5ZPP%ANH(
M#(D8#.H'#`D9C.H&#!'K#`P>ZP(!3^J7#HD93NJ)?MWX&)!.ZH=T#.OU;(CJ
M!`X.Z@4.3^JU!8[J"`X1ZPX.&>L"`1'K"`&$Z@4(W?@@D`CJ#`B(Z@0(#NO\
M;A'K"`A/ZKP,&>L"`=WX*)`)&87J#`0$Z@X$".O^:&Q`3^J^#@P9&>L"`4D9
MC.H.!=WX,)`%Z@@%A>H,!03K^&1-&4_JN`@9ZP(!W?@XD!'K#`&.Z@@,#.H$
M#`7K]&6,Z@X,3^JT!!'K#`P9ZP(!$>L.`8CJ!`[=^$"0#NH%#H[J"`X,Z_5L
M$>L.#D_JM049ZP(!W?A(D!'K"`&$Z@4(".H,"`[K_&Z(Z@0(3^J\#!'K"`@9
MZP(!"1F%Z@P$W?A0D`3J#@1L0`CK_F@,&4_JO@X9ZP(!W?A8D$D9C.H.!07J
M"`4$Z_ADA>H,!4_JN`A-&1GK`@$1ZPP!CNH(#-WX8)`,Z@0,C.H.#`7K]&41
MZPP,3^JT!!GK`@'=^&B0$>L.`8CJ!`X.Z@4.#.OU;([J"`Y/ZK4%$>L.#AGK
M`@$1ZP@!A.H%"`CJ#`@.Z_QNB.H$"$_JO`P1ZP@(&NL"`0D9A>H,!`CK_FD$
MZ@X$W?AX@&Q`3^J^#@D9&.L"!-WX@(!D&8SJ#@4%Z@D%`>OY887J#`5/ZKD)
M9!D8ZP(%%>L,!8[J"0S=^(B`#.H!#(SJ#@P$Z_%D%>L,#$_JL0$8ZP(%W?B0
MH!7K#@6)Z@$.#NH$#@SK]&R.Z@D.3^JT!!7K#@4:ZP(.'NL)#H'J!`D%Z_QH
M">H,"2:=B>H!"4_JO`P>ZPD.JAC=^*"@4AB$Z@P!`>H(`0[K^&YA0$_JN`51
M&$[VH3+&]MEBW?BH@!KK`@H!Z_YA&NL$!(SJ!0J*Z@X*3^J^#A3K"@3=^+"0
M&.L""(7J#@H$Z_%DBNH!"ACK#`Q/ZK$!W?BX@!SK"@P9ZP()CNH!"@SK]&R*
MZ@0*&>L%!4_JM`05ZPH%W?C`D!CK`@B!Z@0*!>O\98KJ#`H8ZPX.3^J\#![K
M"@[=^,B`A.H,"AGK`@F*Z@4*&>L!"0[K]6$9ZPH)3^JU!1CK`@K=^-#@&NL$
M"@GK\62,Z@4)B>H!"4_JL0$:ZPD*'NL""=WXV(`9ZPP)"NOT;(7J`0J*Z@0*
M3^JT!!GK"@D8ZP(*W?C@X!KK!0H)Z_QE@>H$"8GJ#`E/ZKP,&NL)"A[K`@G=
M^.B`&>L!"0KK]6&$Z@P*BNH%"D_JM049ZPH)&.L""-WX\.`8ZP0(">OQ9(SJ
M!0F)Z@$)3^JQ`1CK"0@>ZP(.W?CXH![K#`Z%Z@$,".OT:(SJ!`Q/ZK0$W?@`
MD1[K#`X:ZP(,@>H$"@[K^&Z*Z@@*'.L%#$_JN`@<ZPH,0IV$Z@@*&>L""0SK
M_FR*Z@X*&>L!"4_JO@X9ZPH)1)FM&(CJ#@J*Z@P*+!D)Z_QE3^J\#!3K"@3=
M^!B1CNH,"HD8!.OU9(KJ!0H1ZP@!3^JU!1'K"@&,Z@4*&>L""0'K]&&*Z@0*
MW?@@@1GK#@E/ZK0+&>L*"=WX*.$)Z_%D&.L""(7J"PD8ZPP(B>H!"4_JL0$8
MZPD)W?@PP1[K`@J+Z@$.CNH$#AKK!0H)Z_1E3^JT!!KK#@J!Z@0(W?@XX1SK
M`@R(Z@4('.L+#`KK]6H<ZP@,3^JU!1[K`@)2&(3J!0'=^$#A@>H*`4_JN@A1
M&$OVW$+(]AMR#.OZ;![K`@Y%Z@@*W?A(D1[K!`0*Z@P*!>H(#@'K_&%*Z@X*
M3^J\#!3K"@X9ZP($9!E(Z@P%".H,"MWX4)$-0`[K\6Y%Z@H%3^JQ`2T9&>L"
M"4SJ`009ZP@*#.H!"]WX6)$$Z@X$!>O^943J"P1/ZKX.%.L*!!GK`@D9ZPP)
M0>H.#`'J#@K=^&"!#.H%#`3K]61,Z@H,3^JU!1SK"0P8ZP((&.L!`0SK]&A.
MZ@4,#NH%"MWX:)$,Z@0,3.H*#$_JM`0<ZP$,&>L""47J!`$9ZPX*!>H$"]WX
M<)$!Z@@!#.OX;$'J"P%/ZK@.$>L*`1GK`@D9ZP4*`>O\943J#@%/ZKP)W?AX
M@0'J#`$$Z@X,0>H,`1'K"@P8ZP(!"1E.Z@D$#NH)"MWX@($L0`SK]6Q$Z@H$
M3^JU!6082>H%"ACK`@@$Z_QD&.L."&*93^J\#@KJ#`H)Z@4,2NH,"AKK"`R)
M&!'K"0A%Z@X)!>H."F29">H$"0SK]&Q)Z@H)3^JT!!GK"`B)&$D93NH$!0[J
M!`D%Z@P%1>H)!0CK_&AM&&:93^J\#`7K^&6)&$3J#`D$Z@P*$>L.#@GJ"`EH
MF4GJ"@E/ZK@(&>L."8D8$>L$#@GK]61,Z@@)#.H("FJ9">H%"4GJ"@E/ZK4%
M&>L.#HD8$>L,`4CJ!0P(Z@4)#.H$#$SJ"0P.Z_1N'.L!#&R93^JT!`SK_FR)
M&$7J!`D%Z@0*$>L("`GJ#@ENF4GJ"@E/ZKX.&>L("8D8$>L%"`GK_&5$Z@X)
M!.H."G"9">H,"4GJ"@E/ZKP,&>L("4[J#`B)&`CJ!0@)&0GK]60.Z@P)3^JU
M!4CJ"0A,Z@4)&.L!"'*9#.H%"@GJ!`F)&`CK]&@1ZPX.=)E/ZK0$2>H*"1GK
M#@F)&$7J!`X)Z_AI$>L,"@[J"`Y/ZK@,=ID%Z@0(0V!.Z@@.!.H,"![K"@Z*
M&%(91.H,!07J"05XF47J"`4.Z_ENK1A,\M82S/9B(D_JN0D1ZP((>ID8ZP0(
MC.H)!(3J#@0%Z_YE&.L$"$_JO@Z)&(GJ#@01ZPP,?)EL0`CK]6@<ZP0,3^JU
M!8D8CNH%!!'K"0E^F0SK^&R$Z@@$&>L$"4_JN`B,&("9%.L.!`GK_&Z%Z@@)
MPV")Z@P)3^J\#!3K"001ZP()&>L%"8*9B.H,!03K_F2%Z@X%3^J^#AGK!0F-
M&!7K"`6$F0GK]&B,Z@X)B>H$"4_JM`05ZPD%$>L""1GK#`F&F8[J!`P%Z_AE
MC.H(#$-A&>L,"4_JN`P1ZP((B)D8ZPX(">OU;H3J#`G#88GJ!0E/ZK4%&.L)
M"!'K`@D9ZP0)BID(Z_YDC.H%"(CJ#@A/ZKX.&>L("1'K`@@8ZPP(C)D)Z_1L
MA>H."8GJ!`E/ZK0$&.L)"!'K`@D9ZP4)CID(Z_QECNH$"(CJ#`A/ZKP,&>L(
M"1'K`@@8ZPX(D)D)Z_5NA.H,"8GJ!0E/ZK4%&.L)"!'K`@D9ZP0)DID(Z_YD
MC.H%"(CJ#@A/ZKX.&>L("1'K`@@8ZPP(E)D)Z_1LA>H."8GJ!`E/ZK0$&.L)
M"!'K`@D9ZP4)EID(Z_QECNH$"(CJ#`A/ZKP,&>L("1'K`@@8ZPX(F)D)Z_5N
MA.H,"8GJ!0E/ZK4%&.L)"(D8$>L$"0CK_F2:F8SJ!0B(Z@X(3^J^#AGK"`F)
M&!'K#`@)Z_1LA>H."9R9B>H$"4_JM`08ZPD)B1@)Z_QI31F>F0;KN08&88[J
M!`:&Z@P&3^J\#*T9BAC2&83J#`&!Z@D!$NL.`@7K^652&(%H`NOU8FD8A6D"
M8`)J'.L%!8%@I!@+2L#I"$,)2WI$A6'36!IHH9M:0$_P``,#T0WU(WV]Z/"/
M_??D[`"_R$\!``P!``"01`$`"+6`(/WW*.V?[0][`"*"9X#M`'N?[0Y[@.T"
M>Y_M#GN`[01[G^T.>X#M!GN?[0Y[@.T(>Y_M#GN`[0I[@.T,>PB]`+^O\P"`
M`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````
M````+>GX0P5&%D:`:@`C#$;W%]7I#"$`Z\8,A$7H:G/K```"T@$R0?$``:AO
M!?$X",7I"L-S#T/JQP.;&"MC0>M7<6EC@+L_+D/=IO%`"4_JF19W'`3KAQ<A
M1D-&!/%`#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#^`0L
MZ]$,1BA&__?!^;Q"X=&IZX86,D8Y1D!&_?<D[*YGO>CX@\#Q0`<A1K="0$2H
MOS=&.D;]]QCLJV\[1*MG0"ONT2A&]AL\1/_WH?FYYR=&X.<MZ?!!`?$X!PQ&
MBVH%1@YK@"&3^H/XP_/%`S:Z6ARX&#@J^51$W<+Q0`(`(?WWRNP@1O_W@_DX
M1C@B`"']]\+L($;$Z1QH__=Y^>-X*W`@1F.(:W`C:!L*JW`C:.MPXWHK<6.)
M:W&C:!L*JW&C:.MQXWPK<F.*:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C
M:>MSE/@C,"MT8XQK="-J&PJK="-JZW2]Z/!!_?>JN\+Q.`(`(?WWANS!YRWI
M^$,'1@Q.#$V(1GY$D49]1/WW8.MV&[80"M`$/0`D5?@$/TI&048X1@$TF$>F
M0O;1O>CX@P"_/$$!`#1!`0!P1P"_`DM[1!MH_?>WNP"_4D0!``A`+>D(@+WH
M`0`"`#L````^````"P```#X````0````/@```"4````^````,P```#X````#
M````/@````8````^````%````#X````.````/@````T````^````)````#X`
M```2````/@```"<````^`````@```#X````8````/@````D````^````"@``
M`#X``````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O
M<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0``
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````
M<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S
M8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`
M````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N
M,#4T````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`
M````5$5-4$1)4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A
M<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@7T9(.PIM>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N
M:U]S:7IE.R`C($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D
M8VAU;FM?<VEZ90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(
M+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S
M=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@
M)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T
M(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I
M('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A
M9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I
M;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T
M85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^
M.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG
M97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT
M*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N
M9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF
M9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE
M(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#
M86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM
M?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````<&5R;'AS:2YC
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````.P```#X`
M```+````/@```!`````^````)0```#X````S````/@````,````^````!@``
M`#X````4````/@````X````^````#0```#X````D````/@```!(````^````
M)P```#X````"````/@```!@````^````"0```#X````*````/@``````````
M````8)K_?P$`````````$1@``-$7```!````&P,```$````K`P```0```#L#
M```!````10,```P````\$@``#0```+P[```9````L'P!`!L````$````&@``
M`+1\`0`<````!````/7^_V^T`0``!0```%0)```&````I`(```H```#8!```
M"P```!`````5``````````,```#(?0$``@```.@!```4````$0```!<```!4
M$```$0```'0/```2````X````!,````(````'@````@```#[__]O`0``"/[_
M_V\$#P``____;P,```#P__]O+`X``/K__V\0````````````````````````
M`````````````````````````````````+A\`0```````````$@2``!($@``
M2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!(
M$@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2
M``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(`
M`$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``
M2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!(
M$@``2!(``$@2``"I.P``````````````````````````````````````````
M``!I.P```````$D5````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````!(`!`/____^$/P``M#P```````!T/0``>#T``'@_``"\
M/```@#\```````!D/P``;#\```````",/P``1T-#.B`H1&5B:6%N(#$Q+C(N
M,"TQ-BD@,3$N,BXP`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02
M!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG
M;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!D```````````````$`````````$P````<````"````<`$`
M`'`!```D```````````````$`````````"8````'`````@```)0!``"4`0``
M(```````````````!``````````T````]O__;P(```"T`0``M`$``/`````%
M``````````0````$````/@````L````"````I`(``*0"``"P!@``!@````,`
M```$````$````$8````#`````@```%0)``!4"0``V`0``````````````0``
M``````!.````____;P(````L#@``+`X``-8````%``````````(````"````
M6P```/[__V\"````!`\```0/``!P````!@````,````$`````````&H````)
M`````@```'0/``!T#P``X`````4`````````!`````@```!S````"0```$(`
M``!4$```5!```.@!```%````%0````0````(````?`````$````&````/!(`
M`#P2```,```````````````$`````````'<````!````!@```$@2``!($@``
M``,`````````````!`````0```""`````0````8```!(%0``2!4``'0F````
M``````````@`````````B`````$````&````O#L``+P[```(````````````
M```$`````````(X````!`````@```,0[``#$.P``X$``````````````!```
M``````"6`````0``<((```"D?```I'P```@````-``````````0`````````
MH0````$````"````K'P``*Q\```$```````````````$`````````*L````.
M`````P```+!\`0"P?```!```````````````!`````0```"W````#P````,`
M``"T?`$`M'P```0```````````````0````$````PP````8````#````N'P!
M`+A\```0`0``!@`````````$````"````,P````!`````P```,A]`0#(?0``
M/`$`````````````!`````0```#1`````0````,`````@`$``(```$``````
M``````````0`````````UP````@````#````0(`!`$"````4$```````````
M```$`````````-P````!````,`````````!`@```'P```````````````0``
M``$```#E`````P``<```````````7X```#,```````````````$`````````
H`0````,``````````````)*```#U```````````````!````````````
